@@ -6,7 +6,7 @@ use serde::{Deserialize, Serialize};
 
 use crate::build_system::FlatpakBuildSystem;
 use crate::format::FlatpakManifestFormat;
-use crate::source::{FlatpakSourceItem, ARCHIVE, GIT, PATCH};
+use crate::source::{FlatpakSource, FlatpakSourceItem, ARCHIVE, GIT, PATCH};
 
 #[derive(Clone)]
 #[derive(Deserialize)]
@@ -96,7 +96,8 @@ pub struct FlatpakModule {
     /// Build system to use.
     #[serde(deserialize_with = "crate::build_system::deserialize_from_string")]
     #[serde(serialize_with = "crate::build_system::serialize_to_string")]
-    pub buildsystem: FlatpakBuildSystem,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub buildsystem: Option<FlatpakBuildSystem>,
 
     /// Use a build directory that is separate from the source directory
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -188,7 +189,11 @@ impl FlatpakModule {
             }
         }
         for source in &self.sources {
-            for url in source.get_all_mirror_urls() {
+            let source_description = match source {
+                FlatpakSourceItem::Description(d) => d,
+                FlatpakSourceItem::Path(_p) => continue,
+            };
+            for url in source_description.get_all_mirror_urls() {
                 all_urls.push(url.to_string());
             }
         }
@@ -199,7 +204,10 @@ impl FlatpakModule {
         if self.cmake.unwrap_or(false) {
             return Some(crate::build_system::CMAKE.to_string());
         }
-        return Some(self.buildsystem.to_string());
+        if let Some(buildsystem) = &self.buildsystem {
+            return Some(buildsystem.to_string());
+        }
+        None
     }
 
     pub fn is_patched(&self) -> bool {
@@ -303,7 +311,11 @@ impl FlatpakModule {
             }
         }
         for source in &self.sources {
-            for url in source.get_all_urls() {
+            let source_description = match source {
+                FlatpakSourceItem::Description(d) => d,
+                FlatpakSourceItem::Path(_p) => continue,
+            };
+            for url in source_description.get_all_urls() {
                 all_urls.push(url);
             }
         }
@@ -313,15 +325,14 @@ impl FlatpakModule {
     pub fn get_all_archive_urls(&self) -> Vec<String> {
         let mut all_archive_urls = vec![];
         for source in &self.sources {
-            if source.get_type_name() != ARCHIVE {
+            let source_description = match source {
+                FlatpakSourceItem::Description(d) => d,
+                FlatpakSourceItem::Path(_p) => continue,
+            };
+            if source_description.get_type_name() != ARCHIVE {
                 continue;
             }
 
-            let source_description = match &source {
-                FlatpakSourceItem::Path(_) => continue,
-                FlatpakSourceItem::Description(d) => d,
-            };
-
             let archive_url = match &source_description.url {
                 Some(u) => u,
                 None => continue,
@@ -334,15 +345,14 @@ impl FlatpakModule {
     pub fn get_all_git_urls(&self) -> Vec<String> {
         let mut all_git_urls = vec![];
         for source in &self.sources {
-            if source.get_type_name() != GIT {
+            let source_description = match source {
+                FlatpakSourceItem::Description(d) => d,
+                FlatpakSourceItem::Path(_p) => continue,
+            };
+            if source_description.get_type_name() != GIT {
                 continue;
             }
 
-            let source_description = match &source {
-                FlatpakSourceItem::Path(_) => continue,
-                FlatpakSourceItem::Description(d) => d,
-            };
-
             let git_url = match &source_description.url {
                 Some(u) => u,
                 None => continue,
@@ -375,7 +385,12 @@ impl FlatpakModule {
         // anything after is a patch or an additional file.
         let main_module_source = self.sources.first().unwrap();
 
-        let main_module_source_url: Option<String> = main_module_source.get_url();
+        let main_module_source_description = match main_module_source {
+            FlatpakSourceItem::Description(d) => d,
+            FlatpakSourceItem::Path(_p) => return None,
+        };
+
+        let main_module_source_url: Option<String> = main_module_source_description.get_url();
 
         match &main_module_source_url {
             Some(s) => Some(s.to_string()),
@@ -409,7 +424,12 @@ impl FlatpakModule {
     pub fn is_composite(&self) -> bool {
         let mut code_sources_count = 0;
         for source in &self.sources {
-            let source_type_name = source.get_type_name();
+            let source_description = match source {
+                FlatpakSourceItem::Description(d) => d,
+                FlatpakSourceItem::Path(_) => continue,
+            };
+
+            let source_type_name = source_description.get_type_name();
             if crate::source::CODE_TYPES.contains(&source_type_name) {
                 code_sources_count += 1;
             }
@@ -553,9 +573,7 @@ mod tests {
 
     #[test]
     pub fn test_parse_extra_data() {
-        match FlatpakModule::parse(
-            FlatpakManifestFormat::YAML,
-            r###"
+        let module_manifest = r###"
             name: wps
             buildsystem: simple
             build-commands:
@@ -591,25 +609,45 @@ mod tests {
                   url: https://linux.wps.com/js/meta.js
                   version-pattern: version\s*=\s*"([\d.-]+)"
                   url-pattern: download_link_deb\s*=\s*"(http[s]?://[\w\d$-_@.&+]+)"
-            "###,
-        ) {
-            Err(e) => std::panic::panic_any(e),
-            Ok(module) => {
-                assert_eq!(module.name, "wps");
-            }
-        }
+        "###;
+        let module = FlatpakModule::parse(FlatpakManifestFormat::YAML, module_manifest).unwrap();
+        assert_eq!(module.name, "wps");
     }
 
     #[test]
     pub fn test_parse_helm_files() {
-        assert!(FlatpakModule::parse(
-            FlatpakManifestFormat::YAML,
-            r###"
+        let helm_file = r###"
             name: wps
             sources:
               - "https://github.com/user/repo"
-            "###,
-        )
-        .is_err())
+        "###;
+        assert!(FlatpakModule::parse(FlatpakManifestFormat::YAML, helm_file,).is_err())
+    }
+
+    #[test]
+    pub fn test_parse_no_buildsystem() {
+        let module_manifest = r###"
+            name: dbus-glib
+            sources:
+              - type: archive
+                url: "https://dbus.freedesktop.org/releases/dbus-glib/dbus-glib-0.110.tar.gz"
+                sha256: 7ce4760cf66c69148f6bd6c92feaabb8812dee30846b24cd0f7395c436d7e825
+            config-opts:
+              - "--disable-static"
+              - "--disable-gtk-doc"
+            cleanup:
+              - "*.la"
+              - /bin
+              - /etc
+              - /include
+              - /libexec
+              - /share/gtk-doc
+              - /share/man
+        "###;
+        let flatpak_application = FlatpakModule::parse(FlatpakManifestFormat::YAML, module_manifest).unwrap();
+        assert!(flatpak_application.buildsystem.is_none());
+
+        let application_dump = flatpak_application.dump().unwrap();
+        assert!(!application_dump.contains("buildsystem"))
     }
 }
